# django-unpoly


<p align="center">
<a href="https://pypi.python.org/pypi/django-unpoly">
    <img src="https://img.shields.io/pypi/v/django-unpoly.svg"
        alt = "Release Status">
</a>

<a href="https://github.com/jwaschkau/django-unpoly/actions">
    <img src="https://github.com/jwaschkau/django-unpoly/actions/workflows/main.yml/badge.svg?branch=release" alt="CI Status">
</a>

<a href="https://django-unpoly.readthedocs.io/en/latest/?badge=latest">
    <img src="https://readthedocs.org/projects/django-unpoly/badge/?version=latest" alt="Documentation Status">
</a>

<a href="https://pyup.io/repos/github/jwaschkau/django-unpoly/">
<img src="https://pyup.io/repos/github/jwaschkau/django-unpoly/shield.svg" alt="Updates">
</a>

</p>


Unpoly integration and utilities for Django


* Free software: MIT
* Documentation: <https://jwaschkau.github.io/django-unpoly/>


## Features

* Implements the Unpoly Server protocol (https://unpoly.com/up.protocol)
* Provides utilities for using Unpoly with Django.
* django-debug-toolbar support (https://github.com/jazzband/django-debug-toolbar).
* django-concurrency support (https://github.com/saxix/django-concurrency).

## Credits

This package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter) and the [zillionare/cookiecutter-pypackage](https://github.com/zillionare/cookiecutter-pypackage) project template.
